@@ -8,6 +8,7 @@ import (
 
 	"github.com/emicklei/go-restful"
 
+	corev1 "k8s.io/api/core/v1"
 	kapierror "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
@@ -16,19 +17,19 @@ import (
 	genericapiserver "k8s.io/apiserver/pkg/server"
 	genericmux "k8s.io/apiserver/pkg/server/mux"
 	kubeinformers "k8s.io/client-go/informers"
+	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/restmapper"
 	"k8s.io/klog"
 	openapicontroller "k8s.io/kube-aggregator/pkg/controllers/openapi"
 	"k8s.io/kube-aggregator/pkg/controllers/openapi/aggregator"
 	"k8s.io/kubernetes/pkg/api/legacyscheme"
-	kapi "k8s.io/kubernetes/pkg/apis/core"
-	coreclient "k8s.io/kubernetes/pkg/client/clientset_generated/internalclientset/typed/core/internalversion"
 	rbacrest "k8s.io/kubernetes/pkg/registry/rbac/rest"
 	rbacregistryvalidation "k8s.io/kubernetes/pkg/registry/rbac/validation"
 	rbacauthorizer "k8s.io/kubernetes/plugin/pkg/auth/authorizer/rbac"
 
 	openshiftcontrolplanev1 "github.com/openshift/api/openshiftcontrolplane/v1"
+	operatorinformers "github.com/openshift/client-go/operator/informers/externalversions"
 	quotainformer "github.com/openshift/client-go/quota/informers/externalversions"
 	securityv1client "github.com/openshift/client-go/security/clientset/versioned/typed/security/v1"
 	securityv1informer "github.com/openshift/client-go/security/informers/externalversions"
@@ -65,6 +66,7 @@ type OpenshiftAPIExtraConfig struct {
 
 	QuotaInformers    quotainformer.SharedInformerFactory
 	SecurityInformers securityv1informer.SharedInformerFactory
+	OperatorInformers operatorinformers.SharedInformerFactory
 
 	// these are all required to build our storage
 	RuleResolver   rbacregistryvalidation.AuthorizationRuleResolver
@@ -105,6 +107,9 @@ func (c *OpenshiftAPIExtraConfig) Validate() error {
 	if c.SecurityInformers == nil {
 		ret = append(ret, fmt.Errorf("SecurityInformers is required"))
 	}
+	if c.OperatorInformers == nil {
+		ret = append(ret, fmt.Errorf("OperatorInformers is required"))
+	}
 	if c.RuleResolver == nil {
 		ret = append(ret, fmt.Errorf("RuleResolver is required"))
 	}
@@ -178,7 +183,6 @@ func (c *completedConfig) withAppsAPIServer(delegateAPIServer genericapiserver.D
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -200,13 +204,11 @@ func (c *completedConfig) withAuthorizationAPIServer(delegateAPIServer genericap
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
 
 func (c *completedConfig) withBuildAPIServer(delegateAPIServer genericapiserver.DelegationTarget) (genericapiserver.DelegationTarget, error) {
-
 	cfg := &buildapiserver.BuildServerConfig{
 		GenericConfig: &genericapiserver.RecommendedConfig{Config: *c.GenericConfig.Config, SharedInformerFactory: c.GenericConfig.SharedInformerFactory},
 		ExtraConfig: buildapiserver.ExtraConfig{
@@ -220,7 +222,6 @@ func (c *completedConfig) withBuildAPIServer(delegateAPIServer genericapiserver.
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -236,6 +237,7 @@ func (c *completedConfig) withImageAPIServer(delegateAPIServer genericapiserver.
 			Codecs:                             legacyscheme.Codecs,
 			Scheme:                             legacyscheme.Scheme,
 			AdditionalTrustedCA:                c.ExtraConfig.AdditionalTrustedCA,
+			OperatorInformers:                  c.ExtraConfig.OperatorInformers,
 		},
 	}
 	config := cfg.Complete()
@@ -243,7 +245,6 @@ func (c *completedConfig) withImageAPIServer(delegateAPIServer genericapiserver.
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -263,7 +264,6 @@ func (c *completedConfig) withOAuthAPIServer(delegateAPIServer genericapiserver.
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -287,7 +287,6 @@ func (c *completedConfig) withProjectAPIServer(delegateAPIServer genericapiserve
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -307,7 +306,6 @@ func (c *completedConfig) withQuotaAPIServer(delegateAPIServer genericapiserver.
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -327,7 +325,6 @@ func (c *completedConfig) withRouteAPIServer(delegateAPIServer genericapiserver.
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -349,7 +346,6 @@ func (c *completedConfig) withSecurityAPIServer(delegateAPIServer genericapiserv
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -368,7 +364,6 @@ func (c *completedConfig) withTemplateAPIServer(delegateAPIServer genericapiserv
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
@@ -386,12 +381,11 @@ func (c *completedConfig) withUserAPIServer(delegateAPIServer genericapiserver.D
 	if err != nil {
 		return nil, err
 	}
-	server.GenericAPIServer.PrepareRun() // this triggers openapi construction
 
 	return server.GenericAPIServer, nil
 }
 
-func (c *completedConfig) withOpenAPIAggregationController(delegatedAPIServer *genericapiserver.GenericAPIServer) error {
+func (c *completedConfig) WithOpenAPIAggregationController(delegatedAPIServer *genericapiserver.GenericAPIServer) error {
 	// We must remove openapi config-related fields from the head of the delegation chain that we pass to the OpenAPI aggregation controller.
 	// This is necessary in order to prevent conflicts with the aggregation controller, as it expects the apiserver passed to it to have
 	// no openapi config previously set. An alternative to stripping this data away would be to create and append a new apiserver to the head
@@ -449,10 +443,6 @@ func (c completedConfig) New(delegationTarget genericapiserver.DelegationTarget)
 		return nil, err
 	}
 
-	if err := c.withOpenAPIAggregationController(genericServer); err != nil {
-		return nil, err
-	}
-
 	s := &OpenshiftAPIServer{
 		GenericAPIServer: genericServer,
 	}
@@ -603,10 +593,10 @@ func (c *completedConfig) bootstrapSCC(context genericapiserver.PostStartHookCon
 func (c *completedConfig) EnsureOpenShiftInfraNamespace(context genericapiserver.PostStartHookContext) error {
 	namespaceName := bootstrappolicy.DefaultOpenShiftInfraNamespace
 
-	var coreClient coreclient.CoreInterface
+	var coreClient *corev1client.CoreV1Client
 	err := wait.Poll(1*time.Second, 30*time.Second, func() (bool, error) {
 		var err error
-		coreClient, err = coreclient.NewForConfig(c.ExtraConfig.KubeAPIServerClientConfig)
+		coreClient, err = corev1client.NewForConfig(c.ExtraConfig.KubeAPIServerClientConfig)
 		if err != nil {
 			utilruntime.HandleError(fmt.Errorf("unable to initialize client: %v", err))
 			return false, nil
@@ -618,14 +608,14 @@ func (c *completedConfig) EnsureOpenShiftInfraNamespace(context genericapiserver
 		return err
 	}
 
-	_, err = coreClient.Namespaces().Create(&kapi.Namespace{ObjectMeta: metav1.ObjectMeta{Name: namespaceName}})
+	_, err = coreClient.Namespaces().Create(&corev1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: namespaceName}})
 	if err != nil && !kapierror.IsAlreadyExists(err) {
 		utilruntime.HandleError(fmt.Errorf("error creating namespace %q: %v", namespaceName, err))
 		return err
 	}
 
 	// Ensure we have the bootstrap SA for Nodes
-	_, err = coreClient.ServiceAccounts(namespaceName).Create(&kapi.ServiceAccount{ObjectMeta: metav1.ObjectMeta{Name: bootstrappolicy.InfraNodeBootstrapServiceAccountName}})
+	_, err = coreClient.ServiceAccounts(namespaceName).Create(&corev1.ServiceAccount{ObjectMeta: metav1.ObjectMeta{Name: bootstrappolicy.InfraNodeBootstrapServiceAccountName}})
 	if err != nil && !kapierror.IsAlreadyExists(err) {
 		klog.Errorf("Error creating service account %s/%s: %v", namespaceName, bootstrappolicy.InfraNodeBootstrapServiceAccountName, err)
 	}
